@@ -52,6 +52,6 @@ title case, auto-reference and spell check.
 
 """
 
-from .templating import templates, build, Template, TemplatePackage
+from .templating import Template, TemplatePackage, build, templates
 
 __all__ = ["templates", "build", "Template", "TemplatePackage"]
