@@ -18,9 +18,10 @@ class Serve:
 
     def setup(self, add_arg):
         add_arg("app", help="name of web application")
+        add_arg("port", help="port to serve")
 
     def run(self, stdin, log):
-        web.serve(self.app)
+        web.serve(self.app, self.port)
 
         # from pprint import pprint
         # pprint(web.get_apps())
