@@ -2,12 +2,12 @@
 
 import time
 
-from gevent import spawn
-from gevent.queue import Queue
 import jsonpatch
 import requests
+from gevent import spawn
+from gevent.queue import Queue
 
-from .framework.util import header, tx, json, JSONEncoder, Headers
+from .framework.util import Headers, JSONEncoder, header, json, tx
 from .response import OK, NoContent, Subscription
 
 __all__ = ["publish", "subscribe", "braidify"]
