@@ -240,7 +240,7 @@ def config_servers(root, web_server_config_handler=None):
     )
 
 
-def serve(wsgi_app, workers=2):
+def serve(wsgi_app, port=9300, workers=2):
     # root = pathlib.Path(app.cfg["root"])
     # watch = app.cfg.get("watch")
     # bg = False
@@ -253,7 +253,7 @@ def serve(wsgi_app, workers=2):
 
     proc = sh.gunicorn(
         wsgi_app,
-        bind="0.0.0.0:8100",
+        bind=f"0.0.0.0:{port}",
         worker_class="gevent",
         workers=workers,
         _bg=True,
@@ -670,19 +670,6 @@ class Application:
             self.db = sql.db(f"web-{name}.db")
             self.cache = cache(db=self.db)
 
-        class Database:
-            def get(innerself):
-                return tx.db.tables
-
-        self.route(r"admin/db")(Database)
-        self.add_path_args(table=r"\w+")
-
-        class Table:
-            def get(innerself):
-                return pprint.pformat([dict(r) for r in tx.db.select(innerself.table)])
-
-        self.route(r"admin/db/{table}")(Table)
-
         self.kv = kv.db(f"web-{name}", ":", {"jobs": "list"})
         if static:
             static_path = pkg_resources.resource_filename(static, "static")
@@ -962,10 +949,10 @@ class Application:
             tx.response.status = "500 Internal Server Error"
             tx.response.headers.content_type = "text/html"
             if getattr(tx.user, "is_owner", False):
-                body = config_templates.debug(*sys.exc_info())
+                body = config_templates.traceback(*sys.exc_info())
             else:
                 # TODO body = "Internal server error."
-                body = config_templates.debug(*sys.exc_info())
+                body = config_templates.traceback(*sys.exc_info())
                 # TODO body = self.view.error.internal()
             tx.response.body = body
         exhaust_hooks()  # here for mandatory wrappers (eg. session handling)
@@ -1142,6 +1129,36 @@ def sessions(**defaults):  # TODO XXX
     return hook
 
 
+data_app = application("Data", db=False, mount_prefix="data", table=r"\w+")
+debug_app = application("Debug", db=False, mount_prefix="debug")
+
+
+@data_app.route(r"sql")
+class SQLiteDatabase:
+    """Interface to the SQLite database found at `tx.db`."""
+
+    def get(self):
+        return tx.db.tables
+
+
+@data_app.route(r"sql/{table}")
+class SQLiteTable:
+    """A table in `tx.db`."""
+
+    def get(self):
+        rows = pprint.pformat([dict(r) for r in tx.db.select(self.table)])
+        header("Content-Type", "text/html")
+        return f"<pre>{rows}</pre>"
+
+
+@debug_app.route(r"")
+class Debug:
+    """Render information about the application structure."""
+
+    def get(self):
+        return config_templates.debug(tx.app)
+
+
 session_table_sql = dict(
     timestamp="DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP",
     identifier="TEXT NOT NULL UNIQUE",
