@@ -14,8 +14,16 @@ def generate_cert(domain, cert_dir, challenge_dir):
         sh.openssl("genrsa", "4096", _out=str(private_key))
     csr = cert_dir / "domain.csr"
     if not csr.exists():
-        sh.openssl("req", "-new", "-sha256", "-key", private_key, "-subj",
-                   f"/CN={domain}", _out=str(csr))
+        sh.openssl(
+            "req",
+            "-new",
+            "-sha256",
+            "-key",
+            private_key,
+            "-subj",
+            f"/CN={domain}",
+            _out=str(csr),
+        )
     with (cert_dir / "domain.crt").open("w") as fp:
         fp.write(acme_tiny.get_crt(account_key, csr, challenge_dir))
     csr.unlink()
