@@ -11,12 +11,33 @@ import mimeparse
 
 from . import util
 
-__all__ = ["Accept", "AcceptCharset", "AcceptEncoding", "AcceptLanguage",
-           "Authorization", "Cookie", "Expect", "From", "Host", "IfMatch",
-           "IfModifiedSince", "IfNoneMatch", "IfRange", "IfUnmodifiedSince",
-           "KeepAlive", "MaxForwards", "ProxyAuthorization", "Range",
-           "Referer", "TE", "UserAgent", "XBehavioralAdOptOut",
-           "XDoNotTrack", "XForwardedFor", "XRequestedWith"]
+__all__ = [
+    "Accept",
+    "AcceptCharset",
+    "AcceptEncoding",
+    "AcceptLanguage",
+    "Authorization",
+    "Cookie",
+    "Expect",
+    "From",
+    "Host",
+    "IfMatch",
+    "IfModifiedSince",
+    "IfNoneMatch",
+    "IfRange",
+    "IfUnmodifiedSince",
+    "KeepAlive",
+    "MaxForwards",
+    "ProxyAuthorization",
+    "Range",
+    "Referer",
+    "TE",
+    "UserAgent",
+    "XBehavioralAdOptOut",
+    "XDoNotTrack",
+    "XForwardedFor",
+    "XRequestedWith",
+]
 
 
 class Request(util.Header):
@@ -38,11 +59,12 @@ class _Accept(Request):
                 for param in params.split(";"):
                     k, _, v = param.partition("=")
                     parameters[k.strip()] = v.strip()
-            noq -= .00001
+            noq -= 0.00001
             q = float(parameters.pop("q", noq))
             acceptables.append((q, (value.strip(), parameters)))
-        self.acceptables = [self.type(a[0], _q, **a[1]) for _q, a in
-                            list(reversed(sorted(acceptables)))]
+        self.acceptables = [
+            self.type(a[0], _q, **a[1]) for _q, a in list(reversed(sorted(acceptables)))
+        ]
 
     class _Acceptable:
 
@@ -337,6 +359,7 @@ class UserAgent(Request):
 
     #     print("Success.")
 
+
 # XXX UserAgent._initialize_browscap()
 
 
